@@ -6,11 +6,12 @@ use crate::ignore_directives::{
 };
 use crate::rules::{get_all_rules, LintRule};
 use crate::scopes::Scope;
-use ast_view::{BytePos, RootNode, SourceFile};
+use deno_ast::swc::common::comments::Comment;
+use deno_ast::swc::common::{Span, SyntaxContext};
+use deno_ast::view as ast_view;
+use deno_ast::view::{BytePos, RootNode, SourceFile};
 use std::collections::{HashMap, HashSet};
 use std::time::Instant;
-use swc_common::comments::Comment;
-use swc_common::{Span, SyntaxContext};
 
 /// `Context` stores data needed while performing all lint rules to a file.
 pub struct Context<'view> {
@@ -263,7 +264,7 @@ impl<'view> Context<'view> {
   /// there's no way of knowing what are the "known" rule codes beforehand.
   pub(crate) fn ban_unknown_rule_code(&self) -> Vec<LintDiagnostic> {
     let builtin_all_rule_codes: HashSet<&'static str> =
-      get_all_rules().into_iter().map(|r| r.code()).collect();
+      get_all_rules().iter().map(|r| r.code()).collect();
     let is_unknown_rule = |code: &&String| {
       !builtin_all_rule_codes.contains(code.as_str())
         && !self.plugin_codes.contains(code.as_str())
