@@ -1,11 +1,11 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule};
 use crate::{Program, ProgramRef};
+use deno_ast::swc::common::comments::Comment;
+use deno_ast::swc::common::comments::CommentKind;
+use deno_ast::swc::common::Span;
 use once_cell::sync::Lazy;
 use regex::Regex;
-use swc_common::comments::Comment;
-use swc_common::comments::CommentKind;
-use swc_common::Span;
 
 /// This rule differs from typescript-eslint. In typescript-eslint the following
 /// defaults apply:
@@ -17,6 +17,7 @@ use swc_common::Span;
 /// - ts-expect-error: allowed with comment
 /// - ts-ignore: allowed with comment
 /// - ts-nocheck: allowed with comment
+#[derive(Debug)]
 pub struct BanTsComment;
 
 const CODE: &str = "ban-ts-comment";
