@@ -2,10 +2,12 @@
 use super::{Context, LintRule};
 use crate::handler::{Handler, Traverse};
 use crate::{Program, ProgramRef};
-use ast_view::{Spanned, TsEntityName, TsKeywordTypeKind};
+use deno_ast::view as ast_view;
+use deno_ast::view::{Spanned, TsEntityName, TsKeywordTypeKind};
 use if_chain::if_chain;
 use std::convert::TryFrom;
 
+#[derive(Debug)]
 pub struct BanTypes;
 
 const CODE: &str = "ban-types";
