@@ -1,8 +1,9 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule};
 use crate::{Program, ProgramRef};
-use swc_common::Span;
+use deno_ast::swc::common::Span;
 
+#[derive(Debug)]
 pub struct BanUntaggedIgnore;
 
 const CODE: &str = "ban-untagged-ignore";
