@@ -1,11 +1,12 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule, DUMMY_NODE};
 use crate::ProgramRef;
+use deno_ast::swc::visit::noop_visit_type;
+use deno_ast::swc::visit::Node;
+use deno_ast::swc::visit::Visit;
 use derive_more::Display;
-use swc_ecmascript::visit::noop_visit_type;
-use swc_ecmascript::visit::Node;
-use swc_ecmascript::visit::Visit;
 
+#[derive(Debug)]
 pub struct ExplicitFunctionReturnType;
 
 const CODE: &str = "explicit-function-return-type";
@@ -64,7 +65,7 @@ impl<'c, 'view> Visit for ExplicitFunctionReturnTypeVisitor<'c, 'view> {
 
   fn visit_function(
     &mut self,
-    function: &swc_ecmascript::ast::Function,
+    function: &deno_ast::swc::ast::Function,
     _parent: &dyn Node,
   ) {
     if function.return_type.is_none() {
