@@ -1,13 +1,14 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule, DUMMY_NODE};
 use crate::ProgramRef;
-use derive_more::Display;
-use swc_ecmascript::ast::{
+use deno_ast::swc::ast::{
   ArrowExpr, AssignExpr, CatchClause, Expr, FnDecl, FnExpr, Ident,
   ObjectPatProp, Pat, PatOrExpr, VarDecl,
 };
-use swc_ecmascript::visit::{noop_visit_type, Node, VisitAll, VisitAllWith};
+use deno_ast::swc::visit::{noop_visit_type, Node, VisitAll, VisitAllWith};
+use derive_more::Display;
 
+#[derive(Debug)]
 pub struct NoShadowRestrictedNames;
 
 const CODE: &str = "no-shadow-restricted-names";
