@@ -1,13 +1,14 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
 use super::{Context, LintRule};
 use crate::ProgramRef;
+use deno_ast::swc::common::comments::Comment;
+use deno_ast::swc::common::comments::CommentKind;
+use deno_ast::swc::common::Span;
 use derive_more::Display;
 use once_cell::sync::Lazy;
 use regex::Regex;
-use swc_common::comments::Comment;
-use swc_common::comments::CommentKind;
-use swc_common::Span;
 
+#[derive(Debug)]
 pub struct TripleSlashReference;
 
 const CODE: &str = "triple-slash-reference";
